
PG_DUMP=/usr/bin/pg_dump
PG_DUMPALL=/usr/bin/pg_dumpal

tool_check() {

	if [ -z "$DATABASE" ] ; then
		echo "500 no DATABASE given"
		exit 1
	fi

	if [ "$DATABASE" = "ALL" ] ; then
		if [ ! -x "$PG_DUMPALL" ] ; then
			echo "500 pg_dumpall executable not available"
			exit 1
		fi
	else
		if [ ! -x "$PG_DUMP" ] ; then
			echo "500 pg_dump executable not available"
			exit 1
		fi
	fi
	
}

tool_run() {

	if [ "$DATABASE" = "ALL" ] ; then	
		COMMAND="$PG_DUMPALL"
	else
		COMMAND="$PG_DUMP"
	fi

	is_yes "$DATA_ONLY" && COMMAND="$COMMAND --data-only"
	is_yes "$BLOBS" && COMMAND="$COMMAND --blobs"
	is_yes "$CLEAN" && COMMAND="$COMMAND --clean"
	is_yes "$CREATE" && COMMAND="$COMMAND --create"
	is_yes "$INSERTS" && COMMAND="$COMMAND --inserts"
	is_yes "$ATTR_INSERTS" && COMMAND="$COMMAND --attribute-inserts"
	[ -n "$FORMAT" ] && COMMAND="$COMMAND --format=$FORMAT"
	is_no "$QUOTES" && COMMAND="$COMMAND --no-quotes"
	is_yes "$OIDS" && COMMAND="$COMMAND --oids"
	is_no "$OWNER" && COMMAND="$COMMAND --no-owner"
	is_no "$RECONNECT" && COMMAND="$COMMAND --no-reconnect"
	is_yes "$SCHEMA_ONLY" && COMMAND="$COMMAND --schema-only"
	[ -n "$TABLE" ] && COMMAND="$COMMAND --table=$TABLE"
	is_no "$ACL" && COMMAND="$COMMAND --no-acl"
	[ -n "$PGCOMPRESS" ] && COMMAND="$COMMAND --compress=$PGCOMPRESS"
	[ -n "$PGHOST" ] && COMMAND="$COMMAND --host=$PGHOST"
	[ -n "$PGPORT" ] && COMMAND="$COMMAND --port=$PGPORT"
	
	if [ "$DATABASE" != "ALL" ] ; then	
		COMMAND="$COMMAND $DATABASE"
	fi

	if [ "$1" == "test" ] ; then
		if is_yes "$COMPRESS" ; then
			echo "Command: $COMMAND | gzip -9" >&2
		else
			echo "Command: $COMMAND" >&2
		fi
	else
		if is_yes "$COMPRESS" ; then
			$COMMAND | gzip -9
		else
			$COMMAND
		fi
	fi
}

# vi: syntax=sh
